act.plotting.ContourDisplay
===========================

.. currentmodule:: act.plotting

.. autoclass:: ContourDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ContourDisplay.__init__
      ~ContourDisplay.add_colorbar
      ~ContourDisplay.add_subplots
      ~ContourDisplay.assign_to_figure_axis
      ~ContourDisplay.barbs
      ~ContourDisplay.contour
      ~ContourDisplay.contourf
      ~ContourDisplay.create_contour
      ~ContourDisplay.plot_station
      ~ContourDisplay.plot_vectors_from_spd_dir
      ~ContourDisplay.put_display_in_subplot
   
   

   
   
   